# Kilko Container Management API

This is a crude API client for Kilko Container Manager which manages some of the waste point 
(i.e. trash bins) in various cities in the Netherlands.

Examples of how to use it are included in [main.py](main.py), with the approximate request and response schemas under the
[definitions](src/kilko_waste/definitions) folder.

## Usage
1. Copy `.env.example` to `.env` and use your credentials.
2. Install dependencies.
3. Run `main.py`.

## Notes

This is intended to be adapted to run on Home Assistant as an integration. Feel free to raise an issue.